HEX
Server: Apache/2.4.46 (Win64) OpenSSL/1.1.1j PHP/8.4.25
System: Windows NT DESKTOP-4TAV2RJ 10.0 build 19045 (Windows 10) AMD64
User: fred (0)
PHP: 8.4.25
Disabled: NONE
Upload Files
File: C:/Windows/System32/zh-TW/manage-bde.exe.mui
MZ����@���	�!�L�!This program cannot be run in DOS mode.

$5�<�q�R�q�R�q�R�e���p�R�e�P�p�R�Richq�R�PEL�!~

�,8@ �z8.rdata�@@.rsrc� |@@���
T88���$��8.rdata8x.rdata$zzzdbg �.rsrc$01� (F.rsrc$02 U"'�tTē:�����oб���
�<m>�����(�@�X�p��������� ���!�u� ���MUI������c��X���Q�|‰3�5���[ʤ����MUIzh-TW_x��8T�		��,T		|		�		�
	
	 		P

�

��	D	�	�	�	@@
@@�
@@�@@h#@@,&
@
@�.@@�.@
@�/@@�0@@�1 @ @H2@@�2
	@	@�3
@
@P4@@|4@@@5@@�6
@
@8
@
@ 8@@�8@@9@@P9@@t9@@�9@@�9@@8:@@@@t:!@@0@@>�� F
�
��F
�
��F���G���G��0H���K��L��tL���L��LM���P���V��\Y���Z���[���[��\\���\	�	�^	�	��^	�	��^	�		�_	�	��_	�	�H`
�
��`
�
�a
�
�0a���a���b���c
�
�(f	
�
��i
�
�pl��Dm��o���p��Hr���r��4t��tt���t��Pu�R�[ck(W2�L�-N0

,0�PO(u�vzz��
0�R�[�s(W2�L�-N0

�[te�R�[�s�]�[b0

,0�PO(u�vzz��
0�R�[�s(W�]�[b0

0�s�]��_U BitLocker �Ow�0

��[ck(W2�L�-N0

0�s�]ܕ�� BitLocker �Ow�0

 �x�x@S�R�[�]�}�f\P0

 �x�x@S��[�]�}�f\P0

(�]�f\Pnd��x�x@S�v�S(uzz��0

 �x�x@S�R�[�](W2�L�-N0

 �x�x@S��[�](W2�L�-N0

(�s(Wck(Wnd��x�x@S�v�S(uzz��0

(�s(W�]���[�x�x@S %1!s!

D�jHh "%1!s!" �]�)R�d����[�x�x@S %2!s!0

0�[�x�]�)R�d����[�x�x@S %1!s!0

0�aI��]�)R�d����[�x�x@S %1!s!0

0�[�x�]�)R�d����[�x�x@S %1!s!0

DSID ��RX�%R�Ow�݈n�]�)R�d����[�x�x@S %1!s!0

�x�x@S %1!s! 
N�v��R�d����[�]\P(u0



�la: _U(u��R�d����[Bf��](Wdknj�e�x�x@S
N�^�zܕo��vY�ёp��Ow�

݈n0储`_N��*Rd�dk�Ow�݈n�ˊ8�eQ 

"manage-bde -protectors %1!s! -delete -id %2!s!"0

<�]�_�x�x@S %1!s! �yd�@b	g��R�d����[ёp�0

,    �]2QX[0R�v� %1!s!

4�]*Rd�X�%R�x�p "%1" �vёp��Ow�݈n0

4�]_U(u�x�x@S %1!s! �vёp��Ow�݈n0

4�]\P(u�x�x@S %1!s! �vёp��Ow�݈n0

�x�x@S�]�}GS}0

 �s(Wck(Wnd��S(uzz��0

 �s�]�S�mnd��S(uzz��0

�BitLocker �x�x_j�R�[: -��[�]wQ %1!s! Hr

W�\O
k (C) 2013 Microsoft Corporation. W�\O
k@b	g�&N�OYuNR
k)R0



�manage-bde[.exe] -parameter [arguments]



�c�:

    (W�x�x@S-��[ BitLocker �x�x_j�R�[0



�Sxen�U:

    -status     �c�O/e�c BitLocker KN�x�x@S�vnj
�0

    -on         �R�[�x�x@S�&N��_U BitLocker �Ow�0

    -off        \�x�x@S��[�&Nܕ�� BitLocker �Ow�0

    -pause      �f\P�R�[0��[b�S(uzz��nj�e�bd�0

    -resume     |~�~�R�[0��[b�S(uzz��nj�e�bd�0

    -lock       2�bkX[�S BitLocker �R�[�vnj�e0

    -unlock     AQ1�X[�S BitLocker �R�[�vnj�e0

    -autounlock �{t��R�d����[nj�e�x�x@S0

    -protectors �{t�R�[ёp��v�Ow��e_0

    -SetIdentifier b -si

                �p�x�x@S-��[X�%RkMO0

    -ForceRecovery b -fr

                7_6R BitLocker �Ow��v\Omi�|q}(W͑�e_U�RBf�_�S0

    -changepassword

                �O9enj�e�x�x@S�v�[�x0

    -changepin  �O9e�x�x@S�v PIN0

    -changekey  �O9e�x�x@S�v_U�Rёp�0

    -KeyPackage b -kp

                �p�x�x@S"uuёp�\݈0

    -upgrade    GS} BitLocker Hr,g0

    -WipeFreeSpace b -w

                �bd��x�x@S
N�S(uzz���vnj�e0

    -ComputerName b -cn

                (W�SN��f��WL�0�{�O: "ComputerX"0"127.0.0.1"

    -? b /?    o�:y!|�w��f0�{�O: "-ParameterSet -?"

    -Help b -h o�:y�[te��f0�{�O: "-ParameterSet -h"



�{�O:

    manage-bde -status

    manage-bde -on C: -RecoveryPassword -RecoveryKey F:\

    manage-bde -unlock E: -RecoveryKey F:\84E151C1...7A62067A512.bek

�manage-bde -status [Volume]

                [{-ProtectionAsErrorLevel|-p}]

                [{-ComputerName|-cn} ComputerName]

                [{-?|/?}] [{-Help|-h}]



�c�:

    �c�O/e�c BitLocker KN�x�x@S�vnj
�0



�Sxen�U:

    Volume      �x�x_j�N_� (�_b��R
N�Q_�)0�x�x@S GUID _�b�c�c�v�x

                �x@S0�{�O: "C:"0

                \\?\Volume{26a21bda-a627-11d7-9931-806e6f6e6963}\ b

                "C:\MountVolume"0

    -ProtectionAsErrorLevel b -p

                (u�e��|vyb!k�j0

    -ComputerName b -cn

                (W�SN��f��WL�0�{�O: "ComputerX"0"127.0.0.1"

    -? b /?    o�:y!|�w��f0�{�O: "-ParameterSet -?"

    -Help b -h o�:y�[te��f0�{�O: "-ParameterSet -h"



�{�O:

    manage-bde -status

    manage-bde -status e:

    manage-bde -status e: -ProtectionAsErrorLevel

4manage-bde -status [Volume]

                [{-ProtectionAsErrorLevel|-p}]

                [{-ComputerName|-cn} ComputerName]

                [{-?|/?}] [{-Help|-h}]



�c�:

    �c�O/e�c BitLocker KN�x�x@S�vnj
�0



�Sxen�U:

    Volume      �x�x_j�N_� (�_b��R
N�Q_�)0�x�x@S GUID _�b�c�c�v�x�x

                @S0�{�O: "C:"0

                \\?\Volume{26a21bda-a627-11d7-9931-806e6f6e6963}\ b

                "C:\MountVolume"0�Y�g*g�c�O�go�:y@b	g/e�c BitLocker �v

                �x�x@S0

    -ProtectionAsErrorLevel b -p

                (u�e�d�[yb!k�j0�[g�P�V/���I{}�c�Q�x�x@S/f&T

                �S BitLocker �Ow�0�*gc�[�NUO�x�x@S�bc�[�v

                �x�x@S�S BitLocker �Ow��g�P�VI{} 00&TGRg�P

                �V 10

    -ComputerName b -cn

                (W�SN��f��WL�0�{�O: "ComputerX"0"127.0.0.1"

    -? b /?    o�:y!|�w��f0�{�O: "-ParameterSet -?"

    -Help b -h o�:y�[te��f0�{�O: "-ParameterSet -h"



�{�O:

    manage-bde -status

    manage-bde -status e:

    manage-bde -status e: -ProtectionAsErrorLevel

$manage-bde -on Volume

        [{-RecoveryPassword|-rp} [NumericalPassword] ]

        [{-RecoveryKey|-rk} PathToExternalKeyDirectory]

        [{-StartupKey|-sk} PathToExternalKeyDirectory]

        [{-Certificate|-cert} {-cf PathToCertificateFile|

                               -ct CertificateThumbprint}]

        [{-TPMAndPIN|-tp}]

        [{-TPMAndStartupKey|-tsk} PathToExternalKeyDirectory]

        [{-TPMAndPINAndStartupKey|-tpsk} -tsk

            PathToExternalKeyDirectory]

        [{-Password|-pw}]

        [{-ADAccountOrGroup|-sid} {SID|domain\user|domain\group} [-service]}]

        [{-UsedSpaceOnly|-used}]

        [{-EncryptionMethod|-em}

            {aes128|aes256|xts_aes128|xts_aes256}]

        [{-SkipHardwareTest|-s}]

        [{-Synchronous|-sync}]

        [{-DiscoveryVolumeType|-dv} {FAT32|[none]|[default]}]

        [{-ForceEncryptionType|-fet} {Hardware|Software}]

        [{-RemoveVolumeShadowCopies|-rvsc}]

        [{-ComputerName|-cn} ComputerName]

        [{-?|/?}] [{-Help|-h}]



�c�:

    �R�[�x�x@S�&N��_U BitLocker �Ow�0



�Sxen�U:

    Volume      �x�x_j�N_� (�_b��R
N�Q_�)0�x�x@S GUID _�b�]�c�c�v

                �x�x@S0�{�O: "C:"0

                \\?\Volume{26a21bda-a627-11d7-9931-806e6f6e6963}\ b

                "C:\MountVolume"

    -RecoveryPassword b -rp

                �e�XxeW[�[�x�Ow�݈n0

    -RecoveryKey b -rk

                �e�X(u�e�O�_�vY�ёp��Ow�݈n0

    -StartupKey b -sk

                �e�X(u�e_U�R�vY�ёp��Ow�݈n0

    -Certificate b -cert

                �e�Xnj�e�x�x@S�vlQ��ёp��Ow�݈n0

    -TPMAndPIN b -tp

                �e�X OS �x�x@S�v TPM � PIN �Ow�݈n0

    -TPMAndStartupKey b -tsk

                �e�X OS �x�x@S�v TPM �_U�Rёp��Ow�݈n0

    -TPMAndPINAndStartupKey b -tpsk

                �e�X OS �x�x@S�v TPM � PIN �T_U�Rёp��Ow�݈n0

    -Password b -pw

                �e�X�x�x@S�v�[�xёp��Ow�݈n0

    -ADAccountOrGroup b -sid

                �e�X�x�x@S�v SID �W��RX�%R�Ow�݈n0

    -UsedSpaceOnly b -used

                
\�x�x@S
N�v�s	g�]O(uzz���WL��R�[0

    -EncryptionMethod b -em

                -��[�R�[o�{�l�ёp�'Y\0

    -SkipHardwareTest b -s

                
N2�L�lxԚ,nf��O���Y�R�[0

    -Synchronous b -sync

                7_6R manage-bde I{�_�v0R -on }T�N�[b�6q�_�Qo�:y}T�N�c:y

                W[CQ0

    -DiscoveryVolumeType b -dv

                c�[�c"}�x�x@S��O(u�v�jHh�|q}0

    -ForceEncryptionType b -fet

                7_6R BitLocker O(uߎԚblxԚ�R�[0

    -RemoveVolumeShadowCopies b -rvsc

                7_6R�p�x�x@S*Rd��x�x@Sp�q_���0

    -ComputerName b -cn

                (W�SN��f�
N�WL�0�{�O: "ComputerX"0"127.0.0.1"

    -? b /?    o�:y!|�w��f0�{�O: "-ParameterSet -?"

    -Help b -h o�:y�[te��f0�{�O: "-ParameterSet -h"



�{�O:

    manage-bde -on C: -RecoveryPassword

    manage-bde -on C: -RecoveryKey e:\ -RecoveryPassword

    manage-bde -on C: -rp -rk "f:\Folder" -SkipHardwareTest

    manage-bde -on E: -pw

    manage-bde -on E: -UsedSpaceOnly

    manage-bde -on E: -sid Domain\User

    manage-bde -on E: -sid Domain\Machine$ -service

manage-bde -on Volume

        [{-RecoveryPassword|-rp} [NumericalPassword] ]

        [{-RecoveryKey|-rk} PathToExternalKeyDirectory]

        [{-StartupKey|-sk} PathToExternalKeyDirectory]

        [{-Certificate|-cert} {-cf PathToCertificateFile|

                               -ct CertificateThumbprint}]

        [{-TPMAndPIN|-tp}]

        [{-TPMAndStartupKey|-tsk} PathToExternalKeyDirectory]

        [{-TPMAndPINAndStartupKey|-tpsk} -tsk

            PathToExternalKeyDirectory]

        [{-Password|-pw}]

        [{-ADAccountOrGroup|-sid} {SID|domain\user|domain\group} [-service]}]

        [{-UsedSpaceOnly|-used}]

        [{-EncryptionMethod|-em}

            {aes128|aes256|xts_aes128|xts_aes256}]

        [{-SkipHardwareTest|-s}]

        [{-Synchronous|-sync}]

        [{-DiscoveryVolumeType|-dv} {FAT32|[none]|[default]}]

        [{-ForceEncryptionType|-fet} {Hardware|Software}]

        [{-RemoveVolumeShadowCopies|-rvsc}]

        [{-ComputerName|-cn} ComputerName]

        [{-?|/?}] [{-Help|-h}]



�c�:

    �R�[�x�x@S�&N��_U BitLocker �Ow�0O(u�Sxe�S�p�R�[ёp��R
Nёp��Ow�݈n0

    ��N�Ow�݈n�S�d����[ BitLocker �R�[KNnj�e�vX[�S
k0�Y�g�`�v��f�wQ	g/e�c

    �v TPM�GRg\ TPM �Ow�݈n��R�e�X� OS �x�x@S0
\�e OS �x�x@S�g(WN!k

    ͑�e_U�R&N�[blxԚ,nf�KN�_���Y�R�[0



�Sxen�U:

    Volume      �_��0�x�x_j�N_� (�_b��R
N�Q_�)0�x�x@S GUID _�b�c�c�v

                �x�x@S0�{�O: "C:"0

                \\?\Volume{26a21bda-a627-11d7-9931-806e6f6e6963}\ b

                "C:\MountVolume"

    -RecoveryPassword b -rp

                �e�XxeW[�[�x�Ow�݈n0�Y�g\*g�e�X�[�x�GR�_��e�XKN�_Mb��

                ���Y�R�[0\dk_xeYu}vg"uu��_jxeW[�[�x (�^p�)0��N�[�xwQ	g

                yr�k�v<h_�Bl0ˊ�c�O�NUO_xe (�O�Y "?") �N�����Bl0

    -RecoveryKey b -rk

                �e�X(u�e�O�_�vY�ёp��Ow�݈n (x�(u)0ˊ�c�OS+T2QX[��_j"uu

                KNY�ёp��jHh�vU}
\�v�_0�{�O: "E:"

    -StartupKey b -sk

                �e�X(u�e_U�R�vY�ёp��Ow�݈n0��f��l	g/e�c�v TPM��N

                \*g�e�XY�ёp��Ow�݈n�1\�_��e�X0傁�O(u_U�Rёp��2QX[

                �vY�ёp��jHh�_�MO�e USB �_���x�x_j�v9h�v�0-RecoveryKey

                �T -StartupKey �Sxe��g"uuY�ёp��Ow�݈n��Vdk�S�N�fO(u

                2QX[�v�jHh0

    -Certificate b -cert

                �e�Xnj�e�x�x@S�vlQ��ёp��Ow�݈n0�|q}g�gb�O(u��v�aI�

                X[>e@S�N\~b	gHe�v BitLocker �aI�0傺x�[~b0RNP�aI��1\g

                O(ur��aI�ZP�p BitLocker �R�[�aI�0�~b0RiQP�N
N�v�aI��GR

                \Omig1YWe��N�ar�c�[	gHe BitLocker �aI��vc} (x�(u)0

                �c�O	gHe�aI��jHh�vMOn�b�c�O	gHe BitLocker �aI��vc}�

                �dk�aI�gMO�e,g_j�aI�X[>e@S0

    -TPMAndPIN b -tp

                �e�X OS �x�x@S�v TPM � PIN �Ow�݈n (x�(u)0�|q}g�c:y�`8�eQ

                4-20 MOxe�vxeW[ PIN��k!k_U�R��f�Bf���_�8�eQ�P PIN0�SO(u

                TPM �Ow�g���[�P�Ow�݈n��Vdkg�yd�&N�S�N��f�
N�v�NUO TPM

                �Ow�݈n0

    -TPMAndStartupKey b -tsk

                �e�X OS �x�x@S�v TPM �_U�Rёp��Ow�݈n (x�(u)0傁�O(u_U�R

                ёp��2QX[�v�jHh�_�MO�e USB �_���x�x_j�v9h�v�0�SO(u TPM

                �Ow�g���[�P�Ow�݈n��Vdkg�yd�&N�S�N��f�
N�v�NUO TPM �Ow�

                ݈n0

    -TPMAndPINAndStartupKey b -tpsk

                �e�X OS �x�x@S�v TPM � PIN �T_U�Rёp��Ow�݈n0g�yd��x�x@S

                
N�v�P TPM0TPM �T PIN �N�S TPM �T_U�Rёp��Ow�݈n0

lmanage-bde -off Volume

            [{-ComputerName|-cn} ComputerName]

            [{-?|/?}] [{-Help|-h}]



�c�:

    \�x�x@S��[�&Nܕ�� BitLocker �Ow�0��[�[bBfg�yd�@b	gёp�

    �Ow�݈n0



�Sxen�U:

    Volume      �x�x_j�N_� (�_b��R
N�Q_�)0�x�x@S GUID _�b�c�c�v

                �x�x@S0�{�O: "C:"0

                \\?\Volume{26a21bda-a627-11d7-9931-806e6f6e6963}\ b

                "C:\MountVolume"

    -ComputerName b -cn

                (W�SN��f��WL�0�{�O: "ComputerX"0"127.0.0.1"

    -? b /?    o�:y!|�w��f0�{�O: "-ParameterSet -?"

    -Help b -h o�:y�[te��f0�{�O: "-ParameterSet -h"



�{�O:

    manage-bde -off C:

Lmanage-bde -pause Volume

                  [{-ComputerName|-cn} ComputerName]

                  [{-?|/?}] [{-Help|-h}]



�c�:

    �f\P�R�[0��[bnd��S(uzz��0



�Sxen�U:

    Volume      �x�x_j�N_� (�_b��R
N�Q_�)0�x�x@S GUID _�b�c�c�v

                �x�x@S0�{�O: "C:"0

                \\?\Volume{26a21bda-a627-11d7-9931-806e6f6e6963}\ b

                "C:\MountVolume"

    -ComputerName b -cn

                (W�SN��f��WL�0�{�O: "ComputerX", "127.0.0.1"

    -? b /?    o�:y!|�w��f0�{�O: "-ParameterSet -?"

    -Help b -h o�:y�[te��f0�{�O: "-ParameterSet -h"



�{�O:

    manage-bde -pause C:

Tmanage-bde -resume Volume

                   [{-ComputerName|-cn} ComputerName]

                   [{-?|/?}] [{-Help|-h}]



�c�:

    |~�~�R�[0��[bnd��S(uzz��0



�Sxen�U:

    Volume      �x�x_j�N_� (�_b��R
N�Q_�)0�x�x@S GUID _�b�c�c�v�x�x

                @S0�{�O: "C:"0

                \\?\Volume{26a21bda-a627-11d7-9931-806e6f6e6963}\ b

                "C:\MountVolume"

    -ComputerName b -cn

                (W�SN��f��WL�0�{�O: "ComputerX", "127.0.0.1"

    -? b /?    o�:y!|�w��f0�{�O: "-ParameterSet -?"

    -Help b -h o�:y�[te��f0�{�O: "-ParameterSet -h"



�{�O:

    manage-bde -resume C:

Xmanage-bde -lock Volume {-ForceDismount|-fd}

                              [{-ComputerName|-cn} ComputerName]

                              [{-?|/?}] [{-Help|-h}]



�c�:

    2�bkX[�S BitLocker �R�[�vnj�e0N�e���[nj�e�x�x@S��S	gO(u�x

    �x@S
N�vvQ-NNPёp��Ow�݈nMb��\�[�d����[0
Ng*Rd��NUOёp�

    �Ow�݈n0



�Sxen�U

    Volume      �x�x_j�N_� (�_b��R
N�Q_�)0�x�x@S GUID _�b�c�c�v

                �x�x@S0�{�O: "C:"0

                \\?\Volume{26a21bda-a627-11d7-9931-806e6f6e6963} b

                "C:\MountVolume"

    -ForceDismount b -fd

                sSO�x�x@S�](WO(u-N�_NVf����[r��x�x@S0vu�a(u

                z_ˑ>e�x�x@S�vhsTOX[�S
kBf�1\�S�N���[r��x�x@S0

    -ComputerName b -cn

                (W�SN��f��WL�0�{�O: "ComputerX", "127.0.0.1"

    -? b /?    o�:y!|�w��f0�{�O: "-ParameterSet -?"

    -Help b -h o�:y�[te��f0�{�O: "-ParameterSet -h"



�{�O:

    manage-bde -lock e:

    manage-bde -lock e: -ForceDismount

4manage-bde -unlock Volume

                    {[{-RecoveryPassword| -rp} NumericalPassword] |

                    [{-RecoveryKey|-rk} PathToExternalKeyFile]}

                    [{-Certificate|-cert} {-cf PathToCertificateFile|

                                           -ct CertificateThumbprint} {-pin}]

                    [{-Password|-pw}]

                    [{-ADAccountOrGroup|-sid} [{SID|domain\user|domain\group}]

                    [{-ComputerName|-cn} ComputerName]

                    [{-?|/?}] [{-Help|-h}]



�c�:

    AQ1�O(u�O�_�[�x0�O�_ёp�0�aI�b�[�x��OX[�S BitLocker �R�[�vnj�e0



�Sxen�U:

    Volume      �x�x_j�N_���_b��R
N�Q_�0�x�x@S GUID _b�c�c�v�x�x@S0

                �{�O: "C:"0\\?\Volume{26a21bda-a627-11d7-9931-806e6f6e6963}\

                b "C:\MountVolume"

    -RecoveryPassword b -rp

                �c�O�O�_�[�x�N�d����[�x�x@S0

    -RecoveryKey b -rk

                �c�OY�ёp��jHh�N�d����[�x�x@S0

    -Certificate b -cert

                �gb�,g_jO(u��aI�X[>e@S�\~b�S�d����[�x�x@S�v

                BitLocker �aI�0

    -Password b -pw

                �c:y8�eQ�[�x�N�d����[�x�x@S0

    -ADAccountOrGroup b -sid

                Vf�O(u SID ��RX�%R�Ow�݈n�d����[�x�x@S0

    -ComputerName b -cn

                (W�SN��f��WL�0�{�O: "ComputerX"0"127.0.0.1"

    -? b /?    o�:y!|�w��f0�{�O: "-ParameterSet -?"

    -Help b -h o�:y�[te��f0�{�O: "-ParameterSet -h"



�{�O:

    manage-bde -unlock -?

    manage-bde -unlock e: -RecoveryPassword ...

    manage-bde -unlock e: -RecoveryKey "f:\File Folder\Filename"

    manage-bde -unlock e: -Certificate -cf "c:\File Folder\Filename.cer"

    manage-bde -unlock e: -pw

    manage-bde -unlock e: -sid

�manage-bde -unlock Volume

                    {[{-RecoveryPassword| -rp} NumericalPassword] |

                    [{-RecoveryKey|-rk} PathToExternalKeyFile]}

                    [{-Certificate|-cert} {-cf PathToCertificateFile|

                                           -ct CertificateThumbprint} {-pin}]

                    [{-Password|-pw}]

                    [{-ADAccountOrGroup|-sid} [{SID|domain\user|domain\group}]

                    [{-ComputerName|-cn} ComputerName]

                    [{-?|/?}] [{-Help|-h}]



�c�:

    AQ1�O(u�O�_�[�x0�O�_ёp�0�aI�b�[�x��OX[�S BitLocker �R�[�vnj�e0



�Sxen�U:

    Volume      �_��0�x�x_j�N_���_b��R
N�Q_�0�x�x@S GUID _b�c�c�v

                �x�x@S0�{�O: "C:"0

                \\?\Volume{26a21bda-a627-11d7-9931-806e6f6e6963}\ b

                "C:\MountVolume"

    -RecoveryPassword b -rp

                �c�O�O�_�[�x�N�d����[�x�x@S0HQMR�`�_��]�p�R�[

                �v�x�x@S�^�zxeW[�[�x�Ow�݈n0

    -RecoveryKey b -rk

                �c�OY�ёp��jHh�N�d����[�x�x@S0�*g�c�O

                -RecoveryPassword�GR�_�c�[dk�Sxe0�`HQMR

                �_��]�p�R�[�v�x�x@S�^�zY�ёp��Ow�݈n0

    -Certificate b -cert

                �gb�O(u��v�aI�X[>e@S�\~bvQc}�(u�O�R�[�x�x@SKN

                c}�vT�v�aI�0

                �Y�g~b0R�aI��1\g�b�S�y�[ёp��O�d����[�x�x@S0

                ˊc�[�aI��jHhb�aI��v�aI�c}0�Y�g���PIN Mb��

                X[�S�aI� (�YzfgaaS)�ˊc�[ "-pin" �Sxe��|q}\

                g�c:y�`8�eQ PIN0

    -Password b -pw

                �c:y8�eQ�[�x�N�d����[�x�x@S0

    -ADAccountOrGroup b -sid

                Vf�O(u SID ��RX�%R�Ow�݈n�N�d����[�x�x@S0�Y�g�c�O3^6b

                
T1zb SID�ˊVf�O(u	g�v&{ SID �v�Ow�݈n�d����[0&TGR�

                ˊVf�O(u@b	g SID ��RX�%R�Ow�݈n�N�d����[0

    -ComputerName b -cn

                (W�SN��f��WL�0�{�O: "ComputerX", "127.0.0.1"0

                !q�l� -Certificate Nw�O(u0

    -? b /?    o�:y!|�w��f0�{�O:  "-ParameterSet -?"

    -Help b -h o�:y�[te��f0�{�O: "-ParameterSet -h"



�{�O:

    manage-bde -unlock -?

    manage-bde -unlock e: -RecoveryPassword ...

    manage-bde -unlock e: -RecoveryKey "f:\File Folder\Filename"

    manage-bde -unlock e: -Certificate -cf "C:\File Folder\Filename.cer"

    manage-bde -unlock e: -pw

    manage-bde -unlock e: -sid S-1-5-21-...-513

manage-bde -autounlock -enable Volume



manage-bde -autounlock -disable Volume



manage-bde -autounlock -clearallkeys OSVolume



�c�:

    �{t��R�d����[nj�e�x�x@S0



�Sxen�U:

    Volume      �x�x_j�N_� (�_b��R
N�Q_�)0�x�x@S GUID _�b�c�c�v�x

                �x@S0�{�O: "C:"0

                \\?\Volume{26a21bda-a627-11d7-9931-806e6f6e6963}\ b

                "C:\MountVolume"

    -enable     _U(unj�e�x�x@S�v��R�d����[0

    -disable    \P(unj�e�x�x@S�v��R�d����[0

    -ClearAllKeys

                �yd�\Omi�|q}�x�x@S
N@b	g�]2QX[�vY�ёp�0

    -ComputerName b -cn

                (W�SN��f��WL�0�{�O: "ComputerX"0"127.0.0.1"

    -? b /?    o�:y!|�w��f0�{�O: "-ParameterSet -?"

    -Help b -h o�:y�[te��f0�{�O: "-ParameterSet -h"



�{�O:

    manage-bde -autounlock -enable E:

    manage-bde -autounlock -disable E:

    manage-bde -autounlock -ClearAllKeys C:

�manage-bde -autounlock -enable Volume



manage-bde -autounlock -disable Volume



manage-bde -autounlock -clearallkeys OSVolume



�c�:

    �{t��R�d����[nj�e�x�x@S0



�Sxen�U:

    Volume      �_���Sxe0�x�x_j�N_� (�_b��R
N�Q_�)0�x�x@S

                GUID _�b�c�c�v�x�x@S0�{�O: "C:"0

                \\?\Volume{26a21bda-a627-11d7-9931-806e6f6e6963}\

                b "C:\MountVolume"

    -enable     _U(unj�e�x�x@S�v��R�d����[0dk�R\Og(Wnj�e�x�x

                @S
N�^�zY�ёp��Ow�݈n�&N\ܕo��vY�ёp�2QX[

                (W BitLocker �Ow��v\Omi�|q}�x�x@S0

    -disable    \P(unj�e�x�x@S�v��R�d����[0dk�R\Og�yd�\Omi�|

                q}�x�x@S�v�]2QX[Y�ёp�0傁��_nj�e�x�x@S*Rd�

                Y�ёp��Ow�݈n�����WL�M�Yek_�0

    -ClearAllKeys

                �yd�\Omi�|q}�x�x@S
N@b	g�]2QX[�vY�ёp�0dk�R\O

                g\P(u@b	gܕo�KNnj�e�x�x@S�v��R�d����[0

    -ComputerName b -cn

                (W�SN��f��WL�0�{�O: "ComputerX"0"127.0.0.1"

    -? b /?    o�:y!|�w��f0�{�O: "-ParameterSet -?"

    -Help b -h o�:y�[te��f0�{�O: "-ParameterSet -h"



�{�O:

    manage-bde -autounlock -enable E:

    manage-bde -autounlock -disable E:

    manage-bde -autounlock -ClearAllKeys C:

manage-bde -protectors -get Volume -parameter [arguments]



manage-bde -protectors -add Volume -parameter [arguments]



manage-bde -protectors -delete Volume -parameter [arguments]



manage-bde -protectors -disable Volume -parameter [arguments]



manage-bde -protectors -enable Volume



manage-bde -protectors -adbackup Volume -parameter [arguments]



manage-bde -protectors -aadbackup Volume -parameter [arguments]



�c�:

    �{t�R�[ёp��v�Ow��e_0



�Sxen�U:

    Volume      �x�x_j�N_� (�_b��R
N�Q_�)0�x�x@S GUID _�b�c�c�v�x�x@S0

                �{�O: "C:"0

                \\?\Volume{26a21bda-a627-11d7-9931-806e6f6e6963}\ b

                "C:\MountVolume"

    -get        o�:yёp��Ow��e_0O(u '-?' �S�N��SxeO(u�e_0

    -add        �e�Xёp��Ow��e_0O(u '-?' �S�N��SxeO(u�e_0

    -delete     *Rd�ёp��Ow��e_0O(u '-?' �S�N��SxeO(u�e_0

    -disable    �f\P�Ow�0�S�m
\�x�x
N�R�[ёp��v�Ow���NAQ1��NUO�NX[�S�R�[�v

                nj�e0
Ng�yd��NUOёp��Ow�݈n0

                �Y�g*gc�[x��d'`�v RebootCount �Sxe�(W͑�e_U�R Windows KN�_�

                g��Rb`�_\Omi�|q}�x�x@S�v BitLocker �Ow�0

                �Y�gc�[ RebootCount �Sxe�vu͑�e_U�R Windows �v!kxeT�0R(W

                RebootCount �Sxe-Nc�[�v!kxe�_�\b`�_\Omi�|q}�x�x@S�v

                BitLocker �Ow�0

    -enable     �N��_�x�x�yd�
N�[hQ�v�R�[ёp���N_U(u�Ow�0@b	gёp��Ow�݈n

                ��guHe0

    -adbackup   �P�N�x�x_j�v�O�_nj
�0

    -aadbackup  \�x�x_j�v�O�_nj
��P�N0R Azure Active Directory0

    -ComputerName b -cn

                (W�SN��f��WL�0�{�O: "ComputerX"0"127.0.0.1"

    -? b /?    o�:y!|�w��f0�{�O: "-ParameterSet -?"

    -Help b -h o�:y�[te��f0�{�O: "-ParameterSet -h"



�{�O:

    manage-bde -protectors -add -?

    manage-bde -protectors -get -?

    manage-bde -protectors -disable C:

Lmanage-bde -protectors -add Volume

                [{-ForceUpgrade}]

                [{-RecoveryPassword|-rp} [NumericalPassword]]

                [{-RecoveryKey|-rk} PathToExternalKeyDirectory]

                [{-StartupKey|-sk} PathToExternalKeyDirectory]

                [{-Certificate|-cert} {-cf PathToCertificateFile|

                                       -ct CertificateThumbprint}]

                [-TPM]

                [{-TPMAndPIN|-tp}]

                [{-TPMAndStartupKey|-tsk} PathToExternalKeyDirectory]

                [{-TPMAndPINAndStartupKey|-tpsk} -tsk

                    PathToExternalKeyDirectory]

                [{-Password|-pw}]

                [{-ADAccountOrGroup|-sid} {SID|domain\user|domain\group}

                    [-service]}]

                [{-ComputerName|-cn} ComputerName]

                [{-?|/?}] [{-Help|-h}]



�c�:

    �e�Xёp��Ow��e_0



�Sxen�U:

    Volume      �x�x_j�N_� (�_b��R
N�Q_�)0�x�x@S GUID _�b�c�c�v�x�x

                @S0�{�O: "C:"0

                \\?\Volume{26a21bda-a627-11d7-9931-806e6f6e6963}\ b

                "C:\MountVolume"

    -ForceUpgrade

                7_6RGS} BitLocker Hr,g0

    -RecoveryPassword b -rp

                �e�XxeW[�[�x�Ow�݈n0

    -RecoveryKey b -rk

                �e�X(u�e�O�_�vY�ёp��Ow�݈n0

    -StartupKey b -sk

                �e�X(u�e_U�R�vY�ёp��Ow�݈n0

    -Certificate b -cert

                �e�Xnj�e�x�x@S�vlQ��ёp��Ow�݈n0

    -TPMAndPIN b -tp

                �e�X\Omi�|q}�x�x@S�v TPM �T PIN �Ow�݈n0

    -TPMAndStartupKey b -tsk

                �e�X\Omi�|q}�x�x@S�v TPM �T_U�Rёp��Ow�݈n0

    -TPMAndPINAndStartupKey b -tpsk

                �e�X\Omi�|q}�x�x@S�v TPM �N�S PIN �T_U�Rёp��Ow�݈n0

    -tpm        �e�X\Omi�|q}�x�x@S�v TPM �Ow�݈n0

    -Password b -pw

                �e�Xnj�e�x�x@S�v�[�xёp��Ow�݈n0

    -ADAccountOrGroup or -sid

                �e�X�x�x@S�v SID ��RX�%R�Ow�݈n0

    -ComputerName b -cn

                (W�SN��f��WL�0�{�O: "ComputerX"0"127.0.0.1"

    -? b /?    o�:y!|�w��f0�{�O: "-ParameterSet -?"

    -Help b -h o�:y�[te��f0�{�O: "-ParameterSet -h"



�{�O:

    manage-bde -protectors -add e: -RecoveryPassword

    manage-bde -protectors -add e: -rp -rk h:\

    manage-bde -protectors -add e: -TPMAndPIN

    manage-bde -protectors -add e: -Certificate -cf

        "c:\File Folder\Filename.cer"

    manage-bde -protectors -add e: -pw

    manage-bde -protectors -add e: -sid Domain\User

    manage-bde -protectors -add e: -sid Domain\Machine$ -service

�manage-bde -protectors -add Volume

                [{-RecoveryPassword|-rp} [NumericalPassword]]

                [{-RecoveryKey|-rk} PathToExternalKeyDirectory]

                [{-StartupKey|-sk} PathToExternalKeyDirectory]

                [{-Certificate|-cert} {-cf PathToCertificateFile|

                                       -ct CertificateThumbprint}]

                [-TPM]

                [{-TPMAndPIN|-tp}]

                [{-TPMAndStartupKey|-tsk} PathToExternalKeyDirectory]

                [{-TPMAndPINAndStartupKey|-tpsk} -tsk

                    PathToExternalKeyDirectory]

                [{-Password|-pw}]

                [{-ADAccountOrGroup|-sid} {SID|domain\user|domain\group}

                    [-service]}]

                [{-ComputerName|-cn} ComputerName]

                [{-?|/?}] [{-Help|-h}]



�c�:

    �e�Xёp��Ow��e_0�e�Xёp��Ow�݈nKN�_��S�NO(u 'manage-bde -on'

    2�L��R�[0



�Sxen�U:

    Volume      �_��0�x�x_j�N_� (�_b��R
N�Q_�)0�x�x@S GUID _�

                b�c�c�v�x�x@S0�{�O: "C:"0

                \\?\Volume{26a21bda-a627-11d7-9931-806e6f6e6963}\ b

                "C:\MountVolume"

    -RecoveryPassword b -rp

                �e�XxeW[�[�x�Ow�݈n0�Y�g\*g�e�X�[�x�GR�_�HQ�e�X

                KN�_Mb�����Y�R�[0\dk_xeYu}v�S�N"uu��_jxeW[�[�x

                (�^p�)0��N�[�xwQ	gyr�k<h_��Bl0ˊO(u�NUO_xe

                (�Y "?") �O���S��Bl0

    -RecoveryKey b -rk

                �e�X(u�e�O�_�vY�ёp��Ow�݈n0x�(u0ˊ�c�O(u�O2QX[��_j"uuKNY�ёp��jHh�vU}
\�v�_0�{�O: "E:"

    -StartupKey b -sk

                �e�X(u�e_U�R�vY�ёp��Ow�݈n0�Y�g��f��l	g/e�c

                �v�O�s^�S!jD} (TPM)��N\*g�e�XY�ёp��Ow�݈

                n�1\�_��e�X0傁�O(u_U�Rёp��2QX[�vY�ёp��j

                Hh�_�MO�e USB �_���x�x_j�v9h�v�0

                -RecoveryKey �T -StartupKey �Sxe��g"uuY�ёp��O

                w�݈n��Vdk�S�N�fO(u2QX[�v�jHh0

    -Certificate b -cert

                �e�Xnj�e�x�x@S�vlQ��ёp��Ow�݈n0�gb�O(u��v�aI�

                X[>e@S�O\~b	gHe�v BitLocker �aI�0�Y�g�x�[~b0RNP

                �aI��1\gO(ur��aI�ZP�p BitLocker �R�[�aI�0�Y�g

                ~b0RiQP�N
N�v�aI��GR�d\Og1YWe��N�ar�c�[	gHe

                BitLocker �aI��vc}0x�(u0�c�O	gHe�aI��jHh�vMOn�

                b�c�O	gHe BitLocker �aI��v�aI�c}��dk�aI�gMO�e

                ,g_j�aI�X[>e@S0

    -TPMAndPIN b -tp

                �e�X\Omi�|q}�x�x@S�v TPM �T PIN �Ow�݈n0x�(u0�|q}g

                �c:y�`8�eQ 4-20 MOxe�vxeW[ PIN��k!k_U�R��f�Bf���_�8�eQ

                �P PIN0�SO(u�O�s^�S!jD} (TPM) �Ow�g���[�P�Ow�݈n�

                �Vdkg�yd�&N�S�N��f�
N�v�NUO�O�s^�S!jD} (TPM) �Ow�݈n0

    -TPMAndStartupKey b -tsk

                �e�X\Omi�|q}�x�x@S�v TPM �T_U�Rёp��Ow�݈n0x�(u0

                傁�O(u_U�Rёp��2QX[�v�jHh�_�MO�e USB �_���x�x_j�v

                9h�v�0�SO(u�O�s^�S!jD} (TPM) �Ow�g���[�P�Ow�݈n�

                �Vdkg�yd�&N�S�N��f�
N�v�NUO�O�s^�S!jD} (TPM) �Ow�݈n0

    -TPMAndPINAndStartupKey b -tpsk

                �e�X\Omi�|q}�x�x@S�v TPM �N�S PIN �T_U�Rёp��Ow�݈n0

                g�yd��x�x@S
N�v�P TPM0TPM �T PIN �N�S TPM �T_U�Rёp�

                �Ow�݈n0

    -tpm        �e�X\Omi�|q}�x�x@S�v�O�s^�S!jD} (TPM) �Ow�݈n0�P

                �Ow�݈nc�[�SO(u�O�s^�S!jD} (TPM) �Ow���N�S���[�NUO

                vQ�N�O�s^�S!jD} (TPM) �vܕ�v�Ow�݈n0g�yd��T�S�N TPM

                �T PIN b TPM �T_U�Rёp��Ow�݈n0

    -Password b -pw

                �e�X�x�x@S�v�[�xёp��Ow�݈n0x�(u0�|q}g�c:y�`8�eQ

                (u�O\݈n�d����[�v�[�x0

    -ADAccountOrGroup b -sid

                �e�X�x�x@S�v SID ��RX�%R�Ow�݈n0�Y�gO(u�b��f�	gi�vu�v��

                I���x�x@S\��R�d����[0c�[��f�3^6bBf�ˊ\ '$' D��R0R��f�

                
T1z�&Nc�[ -service �Nc:y�d����[�a|vu�e BitLocker

                
g�R (�^�O(u�) �vgQ�[-N0

    -ComputerName b -cn

                (W�SN��f��WL�0�{�O: "ComputerX"0"127.0.0.1"

    -? b /?    o�:y!|�w��f0�{�O: "-ParameterSet -?"

    -Help b -h o�:y�[te��f0�{�O: "-ParameterSet -h"



�{�O:

    manage-bde -protectors -add e: -RecoveryPassword

    manage-bde -protectors -add e: -rp -rk h:\

    manage-bde -protectors -add e: -TPMAndPIN

    manage-bde -protectors -add e: -Certificate -cf

        "c:\File Folder\Filename.cer"

    manage-bde -protectors -add e: -pw

    manage-bde -protectors -add e: -sid Domain\User

    manage-bde -protectors -add e: -sid Domain\Machine$ -service

�
manage-bde -protectors -get Volume

                            [{-Type|-t} {RecoveryPassword| ExternalKey|

                                         Certificate| TPM| TPMAndStartupKey|

                                         TPMAndPIN| TPMAndPINAndStartupKey|

                                         Password| Identity}]

                            [-ID KeyProtectorID]

                            [{-SaveExternalKey|-sek}

                                PathToExternalKeyDirectory]

                            [{-ComputerName|-cn} ComputerName]

                            [{-?|/?}] [{-Help|-h}]



�c�:

    o�:yёp��Ow��e_0d�^�O(ux��d'`�Sxe�&TGRgo�:y@b	gёp��Ow�݈n0



�Sxen�U:

    Volume      �x�x_j�N_� (�_b��R
N�Q_�)0�x�x@S GUID _�b�c�c�v�x�x

                @S0�{�O: "C:"0

                \\?\Volume{26a21bda-a627-11d7-9931-806e6f6e6963}\ b

                "C:\MountVolume"

    -Type b -t o�:yyr�[^��W�vёp��Ow�݈n0x�(u0

    -id         o�:ywQ	gyr�[X�%RCQ�vёp��Ow�݈n0x�(u0

    -SaveExternalKey b -sek

                �c�O(u�O2QX[o�:yKNY�ёp��jHh�vU}
\�v�_0��NY�

                ёp��jHh�S�NZP�p_U�Rёp�b�O�_ёp�0

    -ComputerName b -cn

                (W�SN��f��WL�0�{�O:"ComputerX"0"127.0.0.1"

    -? b /?    o�:y!|�w��f0�{�O: "-ParameterSet -?"

    -Help b -h o�:y�[te��f0�{�O: "-ParameterSet -h"



�{�O:

    manage-bde -protectors -get C:

    manage-bde -protectors -get C: -Type recoverypassword

    manage-bde -protectors -get C: -SaveExternalKey "f:\Folder"

�manage-bde -protectors -delete Volume

                       [{-Type|-t} {RecoveryPassword| ExternalKey|

                                    Certificate| TPM| TPMAndStartupKey|

                                    TPMAndPIN| TPMAndPINAndStartupKey|

                                    Password| Identity}]

                       [-ID KeyProtectorID]

                       [{-ComputerName|-cn} ComputerName]

                       [{-?|/?}] [{-Help|-h}]



�c�:

    *Rd�ёp��Ow��e_0d�^�O(ux��d'`�Sxe�&TGRg�yd�@b	gёp��Ow�݈n0

    傁�AQ1�|~�~X[�S BitLocker �R�[�vnj�e�ˊ*Rd�g�_NP�Ow�݈n�

    �N\P(u@b	gёp��Ow�݈n0



�Sxen�U:

    Volume      �x�x_j�N_� (�_b��R
N�Q_�)0�x�x@S GUID _�b�c�c�v�x�x

                @S0�{�O: "C:"0

                \\?\Volume{26a21bda-a627-11d7-9931-806e6f6e6963}\ b

                "C:\MountVolume"

    -Type b -t *Rd�yr�[^��W�vёp��Ow�݈n0x�(u0

    -id         *Rd�wQ	gyr�[X�%RCQ�vёp��Ow�݈n0x�(u0

    -ComputerName b -cn

                (W�SN��f��WL�0�{�O:"ComputerX"0"127.0.0.1"

    -? b /?    o�:y!|�w��f0�{�O: "-ParameterSet -?"

    -Help b -h o�:y�[te��f0�{�O: "-ParameterSet -h"



�{�O:

    manage-bde -protectors -delete C: -id {84E151C1...7A62067A512}

    manage-bde -protectors -delete C: -Type TPMAndStartupKey

�/���: Manage-bde !q�l�{tdk Windows Hr,g-N�v�O�s^�S!jD} (TPM)0�Y�g��

�{t�O�s^�S!jD} (TPM)�ˊO(u TPM �{t MMC L]eQ_�{t�UCQb TPM �{t

PowerShell Cmdlet0

tmanage-bde {-forcerecovery|-fr} [Volume]

                          [{-ComputerName|-cn} ComputerName]

                          [{-?|/?}] [{-Help|-h}]



�c�:

    7_6R BitLocker �Ow��v\Omi�|q}(W͑�e_U�RBf2�eQ�_�S!j_0�g�_

    \Omi�|q}�x�x@S*Rd�@b	g�O�s^�S!jD} (TPM) �vܕ�vёp��Ow�݈n0

    N�e͑�e_U�R��f���S	gO(u�O�_�[�xb�O�_ёp�Mb���d����[\Omi�|

    q}0



�Sxen�U:

    Volume      �x�x_j�N_� (�_b��R
N�Q_�)0�x�x@S GUID _�b�c�c�v�x�x@S0

                �{�O: "C:"0\\?\Volume{26a21bda-a627-11d7-9931-806e6f6e6963}\

                b "C:\MountVolume"

    -ComputerName b -cn

                (W�SN��f��WL�0�{�O: "ComputerX", "127.0.0.1"

    -? b /?    o�:y!|�w��f0�{�O: "-ParameterSet -?"

    -Help b -h o�:y�[te��f0�{�O: "-ParameterSet -h"



�{�O:

    manage-bde -fr

    manage-bde -forcerecovery x:

�manage-bde -changepassword [Volume]

                          [{-ComputerName|-cn} ComputerName]

                          [{-?|/?}] [{-Help|-h}]



�c�:

    �O9enj�e�x�x@S�v�[�x0



�Sxen�U:

    Volume      �x�x_j�N_� (�_b��R
N�Q_�)0�x�x@S GUID _�b�c�c�v�x�x

                @S0�{�O: "C:"0

                \\?\Volume{26a21bda-a627-11d7-9931-806e6f6e6963}\ b

                "C:\MountVolume"

    -ComputerName b -cn

                (W�SN��f��WL�0�{�O: "ComputerX"0"127.0.0.1"

    -? b /?    o�:y!|�w��f0�{�O: "-ParameterSet -?"

    -Help b -h o�:y�[te��f0�{�O: "-ParameterSet -h"



�{�O:

    manage-bde -changepassword e:

Tmanage-bde -upgrade Volume

                  [{-ComputerName|-cn} ComputerName]

                  [{-?|/?}] [{-Help|-h}]



�c�:

    GS} BitLocker Hr,g0



�Sxen�U:

    Volume      �x�x_j�N_� (�_b��R
N�Q_�)0�x�x@S GUID _�b�c�c�v�x�x

                @S0�{�O: "C:"0

                \\?\Volume{26a21bda-a627-11d7-9931-806e6f6e6963}\ b

                "C:\MountVolume"

    -ComputerName b -cn

                (W�SN��f��WL�0�{�O: "ComputerX"0"127.0.0.1"

    -? b /?    o�:y!|�w��f0�{�O: "-ParameterSet -?"

    -Help b -h o�:y�[te��f0�{�O: "-ParameterSet -h"



�{�O:

    manage-bde -upgrade C:

�manage-bde -changepin [Volume]

                          [{-ComputerName|-cn} ComputerName]

                          [{-?|/?}] [{-Help|-h}]



�c�:

    �O9e�x�x@S�v PIN0�|q}g�c:y�`8�eQ�e�v PIN0



�Sxen�U:

    Volume      �x�x_j�N_� (�_b��R
N�Q_�)0�x�x@S GUID _�b�c�c�v�x�x

                @S0�{�O: "C:"0

                \\?\Volume{26a21bda-a627-11d7-9931-806e6f6e6963}\ b

                "C:\MountVolume"

    -ComputerName b -cn

                (W�SN��f��WL�0�{�O: "ComputerX"0"127.0.0.1"

    -? b /?    o�:y!|�w��f0�{�O: "-ParameterSet -?"

    -Help b -h o�:y�[te��f0�{�O: "-ParameterSet -h"



�{�O:

    manage-bde -changepin e:

,manage-bde {-changekey} [Volume] PathToExternalKeyDirectory

                          [{-ComputerName|-cn} ComputerName]

                          [{-?|/?}] [{-Help|-h}]



�c�:

    �O9e�N TPM �Ow�݈n�Ow�KN�x�x@S�v_U�Rёp�0



�Sxen�U:

    Volume      �x�x_j�N_� (�_b��R
N�Q_�)0�x�x@S GUID _�b�c�c�v�x�x@S0

                �{�O: "C:"0\\?\Volume{26a21bda-a627-11d7-9931-806e6f6e6963}\

                b "C:\MountVolume"

    PathToExternalKeyDirectory

                ��2QX[�e_U�Rёp��v_0

    -ComputerName b -cn

                (W�SN��f��WL�0�{�O: "ComputerX", "127.0.0.1"

    -? b /?    o�:y!|�w��f0�{�O: "-ParameterSet -?"

    -Help b -h o�:y�[te��f0�{�O: "-ParameterSet -h"



�{�O:

    manage-bde -changekey c: d:\

�manage-bde {-SetIdentifier|-si} Volume

                  [{-ComputerName|-cn} ComputerName]

                  [{-?|/?}] [{-Help|-h}]



�c�:

    \�x�x@S
N�v�x�x@SX�%RCQkMO-��[�p�D}�SGR-Nc�[�v<P0

    �P<P/f1u�`�v�|q}�{t�T@b�{t0



�Sxen�U:

    Volume      �x�x_j�N_� (�_b��R
N�Q_�)0�x�x@S GUID _�b�c�c�v�x�x@S0

                �{�O: "C:"0\\?\Volume{26a21bda-a627-11d7-9931-806e6f6e6963}\

                b "C:\MountVolume"

    -ComputerName b -cn

                (W�SN��f��WL�0�{�O: "ComputerX", "127.0.0.1"

    -? b /?    o�:y!|�w��f0�{�O: "-ParameterSet -?"

    -Help b -h o�:y�[te��f0�{�O: "-ParameterSet -h"



�{�O:

    manage-bde -SetIdentifier C:

lmanage-bde -protectors -adbackup Volume

                       -ID KeyProtectorID

                       [{-ComputerName|-cn} ComputerName]

                       [{-?|/?}] [{-Help|-h}]



�c�:

    �P�N�x�x_j�v�O�_nj
�0



�Sxen�U:

    Volume      �x�x_j�N_� (�_b��R
N�Q_�)0�x�x@S GUID _�b�c�c�v�x�x@S0

                �{�O: "C:"0

                \\?\Volume{26a21bda-a627-11d7-9931-806e6f6e6963}\ b

                "C:\MountVolume"

    -id         O(uyr�[X�%RCQ�P�Nёp��Ow�݈n0

    -ComputerName b -cn

                (W�SN��f�
N�WL�0�{�O: "ComputerX", "127.0.0.1"

    -? b /?    o�:y!|�w��f0�{�O: "-ParameterSet -?"

    -Help b -h o�:y�[te��f0�{�O: "-ParameterSet -h"



�{�O:

    manage-bde -protectors -adbackup C: -id {84E151C1...7A62067A512}

manage-bde {-KeyPackage|-kp} Volume -ID KeyProtectorID

                                    -path PathToKeyPackageDirectory

                  [{-ComputerName|-cn} ComputerName]

                  [{-?|/?}] [{-Help|-h}]

�c�:

    �pc�[�v�x�x@S"uu�e�vёp�\݈0ёp�\݈�S�N�T�O�_�]wQNw�O(u��N�O�_
d

    �k�v�x�x0



�Sxen�U:

    Volume      �x�x_j�N_� (�_b��R
N�Q_�)0�x�x@S GUID _�b�c�c�v�x�x@S0

                �{�O: "C:"0\\?\Volume{26a21bda-a627-11d7-9931-806e6f6e6963}\

                b "C:\MountVolume"

    -id         O(uёp��Ow�݈n-dM�yr�[X�%R�x0

    -path       \�^�zёp�\݈�v�v�_0

    -ComputerName b -cn

                (W�SN��f�
N�WL�0�{�O: "ComputerX"0"127.0.0.1"

    -? b /?    o�:y!|�w��f0�{�O: "-ParameterSet -?"

    -Help b -h o�:y�[te��f0�{�O: "-ParameterSet -h"



�{�O:

    manage-bde -KeyPackage C: -id {84E151C1...7A62067A512} -path "f:\Folder"

�manage-bde {-WipeFreeSpace|-w} Volume

                  [-Cancel]

                  [{-ComputerName|-cn} ComputerName]

                  [{-?|/?}] [{-Help|-h}]

�c�:

    nd��x�x@S
N�v�S(uzz���g�yd��S��X[(Wzz��-N�v�NUOnj�eGr�k0�Y�g�O(u

    �Pnj�ex���R�[�v�x�x@SNw�O(u�@b�c�O�v�Ow�d\}�1\�YT�x�x@S�]O(u�[

    te�R�[x���R�[0



�Sxen�U:

    Volume      �x�x_j�N_� (�_b��R
N�Q_�)0�x�x@S GUID _�b�c�c�v�x�x

                @S0�{�O: "C:"0

                \\?\Volume{26a21bda-a627-11d7-9931-806e6f6e6963}\

                b "C:\\MountVolume"

    -Cancel     �S�mnd��S(uzz��0

    -ComputerName b -cn

                (W�SN��f�
N�WL�0�{�O: "ComputerX"0"127.0.0.1"

    -? b /?    o�:y!|�w��f0�{�O: "-ParameterSet -?"

    -Help b -h o�:y�[te��f0�{�O: "-ParameterSet -h"



�{�O:

    manage-bde -w C:

    manage-bde -w -Cancel C:

�manage-bde -protectors -disable Volume [{-RebootCount|-rc} argument]

                       [{-ComputerName|-cn} ComputerName]

                       [{-?|/?}] [{-Help|-h}]



�c�:

    �f\P�Ow�0�N�\�x�x
N�S(u�v�R�[ёp�-��p*g�S�Ow���NAQ1��NUO�NX[�S�R�[�v

    nj�e0
Ng�yd��NUOёp��Ow�݈n0

    �Y�g*gc�[x��d'`�v RebootCount �Sxe�(W͑�e_U�R Windows KN�_�g��Rb`�_

    \Omi�|q}�x�x@S�v BitLocker �Ow�0�Y�gc�[ RebootCount �Sxe�(W͑�e

    _U�R Windows �v!kxe0RT��e Rebootcount �Sxe-Nc�[�v!kxe�_�g��Rb`�_

    \Omi�|q}�x�x@S�v BitLocker �Ow�0



�Sxen�U:

    Volume      �x�x_j�N_� (�_b��R
N�Q_�)0�x�x@S GUID _�b�c�c�v�x�x@S0

                �{�O: "C:"0

                \\?\Volume{26a21bda-a627-11d7-9931-806e6f6e6963}\ b

                "C:\\\\MountVolume"

    -RebootCount b -rc

                g�f\P�Ow�\Omi�|q}�x�x@S�\�e͑�e_U�R Windows �v!kxe0RT��e

                Rebootcount �Sxe-Nc�[�v!kxe�_b`�_0�S	g 0 �T 15 KN���vxeW[/f

                	gHe_xe0c�[ 0 �S�N!qP�g�f\P�Ow�0

                �Y�g*gc�[dk�Sxe�(W͑�e_U�R Windows KN�_�g��Rb`�_

                \Omi�|q}�x�x@S�v BitLocker �Ow�0

    -ComputerName b -cn

                (W�SN��f�
N�WL�0�{�O: "ComputerX"0"127.0.0.1"

    -? b /?    o�:y!|�w��f0�{�O: "-ParameterSet -?"

    -Help b -h o�:y�[te��f0�{�O: "-ParameterSet -h"



�{�O:

    manage-bde -protectors -disable C: -rc 10

�    -Password b -pw

                �p�x�x@S�e�X�[�xёp��Ow�݈n (x��d'`)0�|q}g�c:y�`8�eQ�[�x�

                �N(W݈n
N��_U BitLocker0

    -ADAccountOrGroup b -sid

                �p�x�x@S�e�X SID �W��RX�%R�Ow�݈n0�O(u�b��f�	gi�vu�v

                ��I���x�x@S\��R�d����[0c�[��f�3^6bBf�ˊD��R '$' 0R��f�

                
T1z�6q�_c�[ -service �Nc:y�d����[�a|vu�e BitLocker 
g�R

                (�^�O(u�) �vgQ�[-N0

    -UsedSpaceOnly b -used

                \�R�[!j_-��[�p0�P�R�[�]O(uzz��
00\g�R�[S+T�]O(uzz��

                KN�x�x@S�v@S�k��
Ng�R�[�S(uzz��0�Y�g*gc�[�\g�R�[@b	g

                �]O(uzz����S(uzz��0

    -EncryptionMethod b -em

                -��[O(u�e*g�R�[�x�x@S�v�R�[o�{�l�ёp�'Y\0�`�S�Nx��d

                AES 128 MOCQ ("aes128")0AES 256 MOCQ ("aes256")0

                XTS-AES 128 MOCQ ("xts_aes128") b XTS-AES 256 MOCQ

                ("xts_aes256")0d�^��SL�c�[�&TGRgO(u AES 128 MOCQ�O�R�[

                �x�x0

    -SkipHardwareTest b -s

                ���Y�R�[�
N2�L�lxԚ,nf� (x��d'`)0�Y�g*gc�[��_�HQ͑�e_U�R

                &N�N�lxԚ,nf��Mbg(W OS �x�x@S
N���Y�R�[0,nf�g�j�g TPM

                /f&T�Y�g,��WL���N�S��_jg����f�/f&T�S�N�_ USB �x�x_j���S

                Y�ёp��jHh0

    -Synchronous b -sync

                7_6R manage-bde I{�_�v0R -on }T�N�[b�6q�_�Qo�:y}T�N�c:y

                W[CQ0�S	g(W��_U BitLocker Bf�Mbi�(udkR�c�Sxe0

    -DiscoveryVolumeType b -dv

                �[��c"}�x�x@S��O(u�v�jHh�|q}0
�Hr Windows !q�l��X��Su

                BitLocker �x�x@S ("[none]"); nj�e\!q�lX[�S�N OS �S��g

                �c�O<h_S�x�x_j�vx��0

                �c"}�x�x@S/f
�Hr Windows ��X��v���u0�[_Ng�c�O�a(uz_��N

                �c�O
\�R�[nj�e�vX[�S0

                �Y�g*gc�[dk�Sxeb "[default]"�GRgO(u FAT32 �c"}�x�x@S

                (�Y�g�x�x@SS+T FAT �jHh�|q})0

    -ForceEncryptionType b -fet

                7_6R BitLocker O(uߎԚblxԚ�R�[0�Y�gc�[ "hardware" �Sxe�

                FO�x�x_j
N/e�clxԚ�R�[�manage-bde g�P�V/���0

                �Y�g�D}�SGR�ybkx��S�v�Sxe�manage-bde g�P�V/���0

    -RemoveVolumeShadowCopies b -rvsc

                7_6R�p�x�x@S*Rd��x�x@Sp�q_���0KN�_�`\!q�lO(uHQMR�v�|q}

                ���Sޞ�O���Sdk�x�x@S0

    -ComputerName b -cn

                (W�SN��f�
N�WL�0�{�O: "ComputerX"0"127.0.0.1"

    -? b /?    o�:y!|�w��f0�{�O: "-ParameterSet -?"

    -Help b -h o�:y�[te��f0�{�O: "-ParameterSet -h"



�{�O:

    manage-bde -on C: -RecoveryPassword

    manage-bde -on C: -RecoveryKey e:\ -RecoveryPassword

    manage-bde -on C: -rp -rk "f:\Folder" -SkipHardwareTest

    manage-bde -on C: -rp -StartupKey "f:\\"

    manage-bde -on C: -rp -TPMAndPIN -em aes128

    manage-bde -on E: -rp -Certificate -cf "C:\File Folder\Filename.cer"

    manage-bde -on E: -pw

    manage-bde -on E: -UsedSpaceOnly

    manage-bde -on E: -sid Domain\User

    manage-bde -on E: -sid Domain\Machine$ -service

 ��f�
T1z: %1!s!

,�x�x@S %1!s! [%2!s!]

[nj�e�x�x@S]

[OS �x�x@S]

����v�R\O:

�    %1!d!0ˊ\dkxeW[�O�_�[�x2QX[(W`���f��v�[hQMOn:



    %2!s!



    �p�MQnj�ez�1Y�ˊ�zsS2QX[dk�[�x0�d����[�R�[�v�x�x@SBf

    �_�8�eQdk�[�x0

P    %1!d!0\S+TY�ёp��jHh�v USB �_���x�x_j�ceQ��f�0

�    %1!d!0͑�e_U�R��f��N�WL�lxԚ,nf�0

    (8�eQ "shutdown /?" �N�S�_}T�NR��f)0

h    %1!d!08�eQ "manage-bde -status" �N�j�glxԚ,nf�/f&Tb�R0

,�la: lxԚ,nf�b�R�_g���Y�R�[0

D�SO(u BitLocker �x�x_j�R�[�Ow��v

�x�x@S:

L    'Y\:                 %1!s! GB

@    I��c�rKa:             %1!s!

D    �R�[~vR�k:           %1!s!%%

@    �R�[�e�l:             %1!s!

L    �Ow��rKa:             %1!s!%2!s!

@    ���[�rKa:             %1!s!

<    ��R�d����[:         %1!s!

8    ёp��Ow�݈n:         ~b
N0R

     ёp��Ow�݈n:

0        %1!s!%2!s!

�/���: lxԚ,nf�1YWe�/����x 0x%1!08x!0�]�yd�@b	gёp��Ow�݈n0



      |vulxԚ,nf�1YWe�v�S���S�VS�b:



      1. ~b
N0RS+TY�ёp��jHh�v USB �_���x�x_j0



      - \S+TY�ёp��jHh�v USB �_���x�x_j�ceQ��f�0

      - �Y�g�N6q1YWe�h�:y��f�!q�l(W��_jBf���S USB �x�x_j0

        �`�S��!q�l(W��_jBf�O(uY�ёp��O�d����[\Omi�|q}

        �x�x@S0



      2. USB �_���x�x_j
N�vY�ёp��jHh�]
d�k0



      - ˊVf�O(uvQ�N USB �_���x�x_j�O2QX[Y�ёp��jHh0



      3. �]ܕ�� TPM0



      - �Y�g���{t�O�s^�S!jD} (TPM)�ˊO(u TPM �{t MMC L]eQ_�{t�UCQb

        TPM �{t PowerShell Cmdlet0



      4. �O�s^�S!jD} (TPM) uP,n0R\Omi�|q}��_jCQ�N	g@b���f0



      - �S�Q��f�-N�v�S��_j�v CD b DVD IQ�x0

      - �Y�g�N6q1YWe�ˊ�j�g�[݈�vg�e̗Ԛ� BIOS GS}��N�S�O�

        s^�S!jD} (TPM) /f&T�]ck8^K�\O0



      5. �c�O�v PIN 
Nck�x0



      6. �O�s^�S!jD} (TPM) 2QX[9hёp� (SRK) wQ	g
N�v�[�v�c
k<P0



      - 傁�͑-�dk<P�ˊ�WL��O�s^�S!jD} (TPM) R�YS�|H�0



      ����v�R\O:



      1. �zl
N�lxԚ,nf�1YWe�vOUL�0

      2. ͑�e�WL�}T�N�N��_U BitLocker0

@    X�%R�xkMO:           %1!s!

��la: �P}T�N&N*g�^�z�NUO�e�vёp��Ow�݈n08�eQ

"manage-bde -protectors -add -?" �N�S�_�e�XvQ�Nёp��Ow�݈n�vs�0}nj
�0

 �la: �R�[�]�}�[b0

��la: �R�[�](W2�L�-N0

8�eQ "manage-bde -status -?" �N�S�_ܕ�e�R�[�rKa�vs�0}nj
�0



�R�[�[b�_g��_U BitLocker �Ow�0

,BitLocker �Ow��]��_U0

<_U(uёp��Ow�݈n�N��_U BitLocker �Ow�0

8    nd�~vR�k:     %1!s!%%

Tck(WVf��WL�Tek�v�x�x@S�[te�R�[0



��S�����N�NBf���ˊ
zP0



\ck(WVf��WL�Tek�v�P�x�x@S�]O(uzz���R�[0



��S�����N�NBf���ˊ
zP0



�(W�^�z�x�x@S�vёp��Ow�݈nKNMR�g�f\P BitLocker �Ow�0

�Y�g��7_6R(Wdk�x�x@S
N_U(u BitLocker �Ow��ˊ�e�Xёp��Ow�݈n0

��la: �Y�g -on �Sxe!q�l�e�Xёp��Ow�݈nb_U�R�R�[�

�Q!kVf� -on KNMR��`�S������Q!k|T�S "manage-bde -off"0

`8�eQ "manage-bde -resume -?" �N�S�_�YUO|~�~�R�[�vs�0}nj
�0

`8�eQ "manage-bde -resume -?" �N�S�_|~�~nd��S(uzz���vnj
�0

\8�eQ "manage-bde -status -?" �N�S�_�x�x@S�rKa�vs�0}nj
�0

$8�eQ�P�aI��v�[�x: %0

08�eQ�[�x�N�d����[�P�x�x@S: %0

,      �]_U(u��R�d����[0

@b	gёp��Ow�݈n

,^��W�p %1!s! �vёp��Ow�݈n

0X�%R�x�p %1!s! �vёp��Ow�݈n

,/���: ~b
N0R�NUOёp��Ow�݈n0

     %1!s!:

,      X�%R�x: %1!s!

H      Y�ёp��jHh
T1z:

        %1!s!

<      �[�x:

        %1!s!

@      �aI�c}:

        %1!s!

x      �aI�c}:

        %1!s!

      f�
T1z:

        %2!s!

<      SID:

        %1!s!

@      3^6b
T1z:

        %1!s!

H        (O(u BitLocker 
g�RgQ�[�d����[)

H      PCR W�I�-��[�j:

        %1!s!

!q%0

<        (O(u�[hQ��_j�O2�L��[te'`W�I�)

 �]�e�X�vёp��Ow�݈n:

08�eQ(u�O�Ow��x�x@S�v PIN: %0

,�Q!k8�eQ PIN �N�N�x��: %0

,8�eQ(u�O�Ow��x�x@S�v�[�x: %0

(�Q!k8�eQ�[�x�N�N�x��: %0

 8�eQ�e�v�[�x: %0

,�Q!k8�eQ�e�v�[�x�N�N�x��: %0

4�x�x@S�]	gg�eHr�v BitLocker0

$�]�)R�f�e�`�v PIN0

$8�eQ�e�v PIN: %0

0�Q!k8�eQ�e�v PIN �N�N�x��: %0

,�x�x@SX�%RCQ�]-��[�p %1!s!0

D�O�_nj
��]b�R�P�N� Active Directory0

<�]�)R�e�v�-N�^�zёp�\݈:

    %1!s!


Nf%0

jd|
Nf%0

�]_U(u%0

�]\P(u%0

�]�[hQ��[%0

�]�[hQ�R�[%0

�R�[2�L�-N%0

��[2�L�-N%0

�]�}�f\P�R�[%0

�]�}�f\P��[%0

�]���[%0

�]�d����[%0

�Ow�ܕ��%0

�Ow���_U%0

!q%0

4AES 128 -dM� Diffuser%0

4AES 256 -dM� Diffuser%0

AES128%0

AES256%0

Y�ёp�%0

( (��R�d����[Bf���)%0

xeW[�[�x%0

TPM%0

 TPM �T_U�Rёp�%0

 TPM �T PIN%0

,TPM �T PIN �T_U�Rёp�%0

$zfgaaS (�aI�_) %0

�[�x%0

D    BitLocker Hr,g:       %1!s!

2.0%0

(Windows Vista%0

!q%0

!q%0

(nj�e�O�_�Nt (�aI�_)%0

 �}� (�aI�_)%0

$�P�R�[�]O(uzz���[b%0

<    �R�[�e�l:    lxԚ�R�[ - %1!s!

��RX�%R%0

  (SID _)%0

0 (iRN %1!u! !k͑�e��_j)%0

$XTS-AES 128%0

$XTS-AES 256%0

lmanage-bde -protectors -adbackup Volume

                       -ID KeyProtectorID

                       [{-ComputerName|-cn} ComputerName]

                       [{-?|/?}] [{-Help|-h}]



�c�:

    �P�N�x�x_j�v�O�_nj
�0



�Sxen�U:

    Volume      �x�x_j�N_� (�_b��R
N�Q_�)0�x�x@S GUID _�b�c�c�v�x�x@S0

                �{�O: "C:"0

                \\?\Volume{26a21bda-a627-11d7-9931-806e6f6e6963}\ b

                "C:\MountVolume"

    -id        �P�NwQ	gyr�[X�%R�x�vёp��Ow�݈n0

    -ComputerName b -cn

                (W�SN��f�
N�WL�0�{�O: "ComputerX", "127.0.0.1"

    -? b /?    o�:y!|�w��f0�{�O: "-ParameterSet -?"

    -Help b -h o�:y�[te��f0�{�O: "-ParameterSet -h"



�{�O:

    manage-bde -protectors -adbackup C: -id {84E151C1...7A62067A512}

P�O�_nj
��]b�R�P�N� Azure Active Directory0

8AES 128 (1uX[>e݈n�c6RhV��R)%0

8AES 256 (1uX[>e݈n�c6RhV��R)%0

@XTS-AES 128 (1uX[>e݈n�c6RhV��R)%0

@XTS-AES 256 (1uX[>e݈n�c6RhV��R)%0

hf�JT: 
N/e�c manage-bde.wsf c�N�x0ˊO(u manage-bde.exe0

Tf�JT: *g�e�XxeW[�[�x0��f�
N�v FIPS �D}�SGR-��[�ybk�^�z�O�_�[�x0

�f�JT: "%1!s!" *g�e�X�x�x@S0

dk3^6b�v SID ��RX�%R�Ow�݈n�]X[(Wdk�x�x@S-N0

dk�x�x@S�SAQ1�NP3^6bO(uNP SID ��RX�%R�Ow�݈n0



df�JT: �]�)R�WL�}T�N�
NN���vj��f�
N
N/e�c�pdk}T�Nc�[�v
x��d'`�Sxe��V��]���_eu0

D�S	gO(u�O�_�[�xb�O�_ёp�Mb���d����[�x�x@S %1!s!0

P/���: -cn b -ComputerName �v�_b��_��cW���f�
T1z

$/���: !q�lc�[Y��f�

$/���: !q�lc�[YP�x�x@S

$/���: ���	g�x�x@S�N_�0

4/���: !q�l�WL��d\O��V�p�x�x@S�]���[0

T/���: X[�S�_��nj�n�vVf����b0



ˊ�x���`�d	g��f��v�|q}�{t
kP�0

�/���: #��}0R BitLocker �{t�Nb�Bf|vu/���0



�Y�g�]c�[ "-cn" �Sxe�ˊ�j�g��f�
T1z/f&Tck�x0

</���: |vu/��� (�N�x 0x%1!08x!):

|/���: ���l
Nck�x0

!q�l�N� "%1!s!"0



ˊ8�eQ "manage-bde -?" �N�N�O(u�e_0

�/���: ���l
Nck�x0

!q�l(WTNP}T�N-NY!kc�[ "%1!s!"0



ˊ8�eQ "manage-bde -?" �N�N�O(u�e_0

4/���: "%1!s!" �Sxe�_�	g_xe0

d/���: z�1Y�_���v�Sxe0



ˊ8�eQ "manage-bde -?" �N�N�O(u�e_0

8/���: �WL��d\OBf�CQ�NaY�P�V FALSE0

 /���: 8�eQ�v<P
N&{0

H/���: 8�eQ�v<P���QAQ1��vw��^
NP�:

%1!d! PW[CQ0

L/���: �l	g�SO(u BitLocker �x�x_j�R�[�Ow��v�x�x@S0

�/���: BitLocker !q�l��_U�x�x@S %1!s!0

�S�V�S��/fr��x�x@S
NX[(W�b�[
N/f	gHe�v BitLocker �x�x@S0

�/���: �_�c�[ '-StartupKey' b '-Password' �Sxe�Mb��O(u BitLocker �O�Ow�

\Omi�|q}�x�x@S0



�Y�s�0}nj
��ˊ8�eQ "manage-bde -on -?"0

�/���: �_�	gxeW[�O�_�[�xMb����_U BitLocker �Ow�0



(W}T�N-N�R
N "-RecoveryPassword"�sS�S��_j"uu�PxeW[�[�x0



�Y�s�0}nj
��ˊ8�eQ "manage-bde -on -help"0

�/���: �_�	g�_�S�e�lMb����_U BitLocker0(W}T�NR-N�R
N

"-RecoveryKey [path]"�sS�S"uu&N2QX[�P�O�_ёp�0



*g�e�X�NUOёp��Ow�݈n0

,/���: *gc�[�NUOёp��Ow�݈n0

�/���: �R�[�e�l '%1!s!' !qHe0



	gHe�v�R�[�e�l: aes1280aes2560xts_aes1280xts_aes2560



�R�[�e�l aes128_diffuser � aes256_diffuser �]N�Bf0

�/���: TPM !q�l(u�O�Ow�dk�x�x@S0

TPM 2QX[9hёp� (SRK) wQ	g
N�v�[�v�c
k<P0



傁�͑-�dk<P�ˊ�WL� TPM R�YS�|H� (tpminit.exe)0

�/���: TPM !q�l(u�O�Ow�dk�x�x@S0�]ܕ�� TPM0



�Y�g���{t�O�s^�S!jD} (TPM)�ˊO(u TPM �{t MMC L]eQ_�{t�UCQb

TPM �{t PowerShell Cmdlet0

�/���: TPM !q�l(u�O�Ow�dk�x�x@S0*g-��[ TPM �d	g�0



�Y�g���{t�O�s^�S!jD} (TPM)�ˊO(u TPM �{t MMC L]eQ_�{t�UCQb

TPM �{t PowerShell Cmdlet0

�/���: TPM !q�l(u�O�Ow�dk�x�x@S0�]ܕ�� TPM0



�Y�g���{t�O�s^�S!jD} (TPM)�ˊO(u TPM �{t MMC L]eQ_�{t�UCQb TPM

�{t PowerShell Cmdlet0

�/���: �c"}�x�x@S^��W '%1!s!' 
Nck�x0



ck�x�v�x�x@S�c"}^��W�YN: FAT320[none]0[default]0

h/���: �vj��f��P�V�c"}�x�x@S_xe�v/���0


�Hr�v Windows 
N/e�c�^�z�c"}�x�x@S0

�/���: �Y�g��(W�HQ�[݈�t�Xb�O�_�t�X-N��_U BitLocker�TPM �_�X[(W�&N�]_U(u

�S_U�R0�Y�g��f�+T	g TPM�ˊ\ BIOS -��pAQ1�\Omi�|q}O(u TPM0

�/���: �Y�g��(W�HQ�[݈�t�Xb�O�_�t�X-N��_U BitLocker��_�_U(u&N_U�R TPM0



�Y�g���{t�O�s^�S!jD} (TPM)�ˊO(u TPM �{t MMC L]eQ_�{t�UCQb

TPM �{t PowerShell Cmdlet0

�/���: �Y�g��(Wdk�x�x@S
N��_U BitLocker �N-dM� SID ��RX�%R�Ow�݈n��`�_�

�c�O�\NP(u�e�O�_�vM�Y�Ow�݈n0

`/���: !qHe�v�R�[^��W '%1!s!'0



	gHe�v�x�x@S�R�[^��W: lxԚ0ߎԚ0

�/���: �R�[�e�l aes128_Diffuser � aes256_Diffuser �]N�Bf0



	gHe�v�x�x@S�R�[�e�l: aes1280aes2560xts_aes1280xts_aes2560

�/���: !q�l(W�x�x@S_U(u BitLocker��VvQS+T�x�x@Sp�q_���0

O(u -RemoveVolumeShadowCopies x���S�N*Rd�@b	g�x�x@S

p�q_���0�`KN�_\!q�lO(uHQMR�v�|q}���Sޞ�O���Sdk�x�x@S0

h/���: dk�x�x@S�]2QX[�S��R�d����[vQ�N�x�x@S�vY�ёp�0

�`�_�HQ�yd���Nёp��Mb����[dk�x�x@S0



����v�R\O:



1. �p�MQnj�ez�1Y�ˊ�j�gܕo��vnj�e�x�x@S/f&T	g�O�_�[�x

   b�O�_ёp�0

2. 8�eQ "manage-bde -autounlock -ClearAllKeys Volume"

   �yd��]2QX[�vY�ёp�0

|}T�N!qHe0�l	g�NUOI��cck(W2�L�0

�Y�s�0}nj
��ˊ8�eQ "manage-bde -status %1!s!"0

 �x�x@S�R�[�]�}�f\P0

 �x�x@S��[�]�}�f\P0

(�]�f\Pnd��x�x@S�v�S(uzz��0

t}T�N!qHe0�l	g�f\PI��c0

�Y�s�0}nj
��ˊ8�eQ "manage-bde -status %1!s!"0

 �x�x@S�R�[�](W2�L�-N0

 �x�x@S��[�](W2�L�-N0

$�](Wnd��x�x@S�v�S(uzz��0

$/���: �]�}���[�x�x@S0

H/���: �V�p�x�x@SS+T�WL�-N�v\Omi�|q}�@b�N!q�l���[dk�x�x@S0

/���: Vf����[�x�x@SBfX[�S���b0�S��	g�a(uz_ck(WX[�Sdk�x�x

@S (�N�x 0x80070005)0



�ReQ "-ForceDismount" �Sxe�N���[�x�x@S (sSO�x�x@S�](WO(u-N)0



ˊ8�eQ "manage-bde -lock -?" �S�_s�0}nj
�0

$/���: �x�x@S�]�d����[0

0/���: Vf��_�x�x���Sёp�Bf|vu/���0

H/���: �jHh "%1!s!" !q�l�d����[�x�x@S %2!s!0

8/���: �[�x!q�l�d����[�x�x@S %1!s!0

8/���: �aI�!q�l�d����[�x�x@S %1!s!0

T/���: �_�c�[�d����[_j6R (�[�x0SID0�aI�0�O�_�[�xb�O�_ёp�)0

8/���: �[�x!q�l�d����[�x�x@S %1!s!0

T/���: 
NAQ1�`��z�WL�dk�d\O�

�`�_�(W,g_j{veQ��f��Mb���WL�dk}T�N0

X/���: �S��c�[NP�d����[_j6R (�[�x0SID0�aI�0�O�_�[�xb�O�_ёp�)0

L/���: SID ��RX�%R�Ow�݈n!q�l�d����[�x�x@S %1!s!0

</���: 
N�S�N(W\Omi�|q}�x�x@S
NO(u��R�d����[0

0/���: �x�x@S
N�]_U(u��R�d����[0

0/���: �x�x@S
N�]\P(u��R�d����[0

|/���: �S	g(W\Omi�|q}�x�x@S-NMb��~b0R(u�N��R�d����[nj�e�x�x@S�v

ёp�0�`�_�c�[\Omi�|q}�x�x@S�v�x�x@S�N_�0

@/���: 
Nck�x�v�Ow�݈n^��W '%1!s!'0



ck�x�v�Ow�݈n^��W: RecoveryPassword0ExternalKey0Certificate0TPM0

TPMAndStartupKey0TPMAndPIN0TPMAndPINAndStartupKey0Passwor �N�S Identity0

8/���: �b�S�x�x@S�vёp��Ow�݈nBf|vu/���0

0/���: !q�lX�%Rc�[�v�Ow�݈nX�%R�x0

P/���: ёp�!q�l2QX[0R�v
\_0ˊO(uU}
\_��O�Y "D:\\"0

4/���: Vf�\ёp�2QX[0R�x�xBf|vu/���0

0/���: *Rd�ёp��Ow�݈nBf|vu/���0

��la: �]\P(u�x�x@S %1!s! �vёp��Ow�݈n�NAQ1�|~�~X[�S BitLocker �R�[�v

nj�e0



8�eQ "manage-bde -protectors -enable %1!s!" �N͑�e_U(u�]�e�X�v�NUOёp��Ow�

݈n0

H/���: �_�O(u�aI�L]eQ_�{t�UCQ

�yd�nj�e�O�_�Nt�aI�0

�/���: �}��d����[�S��(W BitLocker �x�x_j�R�[�D}�SGR-��[0_U�RBfAQ1��}��d�

���[
0-N\P(u�b�N��yd��}�W�c6R�z
N�vlQ��ёp��SGR�D}�SGR-��[0BitLocker �x�x

_j�R�[�}��d����[�aI�
0�O\P(u0

8/���: !q�lTBfO(u -type � -id0

8/���: �`�_�O(u -tsk c�[_U�Rёp�0

\/���: ���f��l	g TPM�b�l	g�S� BitLocker -dM�O(u�v TPM0

</���: �S	g\Omi�|q}�x�x@SMb���S TPM �Ow�0

P/���: c�[ -tpm Bf
N�S��NUOvQ�N TPM ёp��Ow�݈n-dM�0

�/���: 傁�O(u -Certificate }T�N��`�_�TBfO(u -cf �Sxec�[�aI��jHh�v_�bO(u -ct �Sxec�[�aI�c}0

�/���: 9h�dxeW[�[�x�v��Bl��O�_�[�x�v<h_
Nck�x0



�[�x�_�S+T 48 MOxe��[/f 8 D} 6 MOxe�vxeW[0

ˊ(W}T�NRO(u#�W[_� (-) �OR�� 6 MOxe�v�D}0



48 PMOxeKNxeW[�[�x-N�v�kP 6 MOxe�D}�_�:

1. �S1u 11 ted�

2. \�e 720896



�O�Y "000000" /fck�x�v 6 MOxe�D}0


Nck�x�v�D}S�b "123456"0"720896" �N�S "888888"0



O(u "-rp" 
N�R_xe�S�N"uu��_j�[�x0

�/���: BitLocker (W��f�-N|v�s�S��_j�v CD b DVD IQ�x0�S��_j�v CD b

DVD IQ�xg\� TPM !q�l�d����[\Omi�|q}�x�x@S0



����v�R\O:



1. �S�Q��f�-N�v�S��_j CD b DVD IQ�x0

2. �WL� "manage-bde -off %1!s!" ���S
\�x�x@bZP�v�NUO���f0

3. ͑�e_U�R��f�0

   (8�eQ "shutdown /?" �N�S�_}T�NR��f)0

4. �Q�WL�N!kdk}T�N0

$/���: ~b
N0R	gHe�v�aI�0

�/���: ~b0RiQP�N
N�v	gHe�aI�0O(u -cf �Sxec�[�aI��jHh�v_�bO(u -ct �Sxec�[�aI�c}�&N͑�e�WL�dk}T�N��Nc�[/UN�v�aI�0

X/���: !qHe�v���l0

"%1!s!" !q�l��X��p	gHe�v SID b3^6b
T1z0

|/���: BitLocker �x�x_j�R�[!q�l�WL�dk}T�N0

�vj��f��WL��v�S��/f
N/e�cdk}T�N�v
�Hr Windows0

�/���: �x�x@S %1!s! �l	g�NUO�S(u�v�_�S�e�l0

8�eQ "manage-bde -protectors -add -?" �S�_�e�X�O�_�[�xb�O�_ёp��vs�0}nj
�0

�/���: �_���_U BitLocker �Ow���N7_6R�_�S�x�x@S %1!s!0

�Y�s�0}nj
��ˊ8�eQ "manage-bde -on -?"0

4/���: dk�x�x@S�l	gёp��Ow�݈n�S�O*Rd�0

D
N�ZP�NUO���f�1\�S�N7_6R�WL��x�x@S %1!s! �v�_�S0

�/���: �x�x@S %1!s! 
N�l	g�[�xёp��Ow�݈n0

�Y��e�X�[�xёp��Ow�݈n�vs�0}nj
��

ˊ8�eQ "manage-bde -protectors -add -?"0

�/���: �x�x@S %1!s! 
N	gYP�[�xёp��Ow�݈n0

�kP�x�x@S�S/e�cNP�[�xёp��Ow�݈n0ˊ8�eQ

"manage-bde -protectors -delete -?" �N�S�_*Rd�

ёp��Ow�݈n�vs�0}nj
�0

�/���: �x�x@S %1!s! 
N�l	g PIN ёp��Ow�݈n0

8�eQ "manage-bde -protectors -add -?" �N�S

�_�e�X PIN ёp��Ow�݈n�vs�0}nj
�0

�/���: �x�x@S %1!s! 
N	gYP PIN ёp��Ow�݈n0

�kP�x�x@S�S/e�cNP PIN ёp��Ow�݈n0�Y�*Rd�ёp��Ow�݈n�vs�0}nj
��

ˊ8�eQ "manage-bde -protectors -delete -?"0

P/���: *gO(u -Certificate �Sxec�[�aI�c}b�aI��jHh0

�/���: �x�x@S %1!s! 
N�l	g TPM _U�Rёp��Ow�݈n0

�Y��e�X_U�Rёp��Ow�݈n�vs�0}nj
��ˊ8�eQ "manage-bde -protectors -add -?"0

�/���: �x�x@S %1!s! 
N	gYP_U�Rёp��Ow�݈n0

�kP�x�x@S�S/e�cNP_U�Rёp��Ow�݈n0�Y�*Rd�ёp��Ow�݈n�vs�0}nj
��

ˊ8�eQ "manage-bde -protectors -delete -?"0

@/���: ���c�[ '-ID' �Sxe�Mb���P�N�O�_nj
�0

l/���: �D}�SGR
NAQ1�\�O�_nj
�2QX[0R Active Directory0

\
NgVf�r��d\O0

8/���: �S��(W�[te�R�[�v�x�x@S-Nnd��S(uzz��0

8/���: !q�l(WlxԚ�R�[�v�x�x@S-Nnd��S(uzz��0

0/���: �vMR*g2�L��S(uzz��nd�\Omi0

�4VS_VERSION_INFO��
{aJ
{aJ?StringFileInfo�040404B0LCompanyNameMicrosoft CorporationTFileDescriptionBitLocker �x�x_j�R�[: -��[�]wQn'FileVersion10.0.19041.7291 (WinBuild.160101.0800)>InternalNamemanage-bde.exe�.LegalCopyright� Microsoft Corporation. All rights reserved.NOriginalFilenamemanage-bde.exe.muij%ProductNameMicrosoft� Windows� Operating SystemDProductVersion10.0.19041.7291DVarFileInfo$Translation�PADDINGXXPADDINGPADDINGXXPADDINGPADDINGXXPADDINGPADDINGXXPADDINGPADDINGXXPADDINGPADDINGXXPADDINGPADDINGXXPADDINGPADDINGXXPADDINGPADDINGXXPADDINGPADDINGXXPADDINGPADDINGXXPADDINGPADDINGXXPADDINGPADDINGXXPADDINGPADDINGXXPADDINGPADDINGXXPADDINGPADDINGXXPADDINGPADDINGXXPADDINGPADDINGXXPADDINGPADDINGXXPADDINGPADD